encode

Function encode 

pub fn encode(sockets: &[PublishedSocket]) -> String
Encode a list of published sockets for the guest env var, as port|dir|guest_path entries joined by ;. Paths cannot contain ; or | in any realistic case; entries that would are rejected by the host before encoding (see the host-side validator).